// Copyright 2012 Google Inc. All Rights Reserved.

/**
 * @fileoverview Implementation of the communication protocol between an
 * action menu in JavaScript and the native app.
 * @author jenns@google.com (Jennifer Stubleuy)
 */

(function() {
  if (!navigator || navigator.actionMenuNativeMessaging) {
    return;
  }

  var messagingApi = {
    apiVersion: 1
  };

 /**
  * Called by the Javascript to hide the native icon action menu.
  */
 messagingApi.hideNativeIconActionMenu = function() {
   navigator.googleInternal.dispatch('actionmenumessaging',
     'hideNativeIconActionMenu');
 };

  /**
   * The JS callback for when the icon action menu is hidden.
   * @type {!function())|undefined}
   * @private
   */
  messagingApi.onIconActionMenuHideCallback_;

  /**
   * Called by the Javascript to show the native icon action menu.
   * @param {string} config Serialized proto array representing the
   *     ActionMenuConfig to render.
   * @param {!function()=} opt_onnHideCallback The JS function to call when the
   *     menu is hidden.
   */
  messagingApi.showNativeIconActionMenu = function(config, opt_onHideCallback) {
    this.onIconActionMenuHideCallback_ = opt_onHideCallback;
    navigator.googleInternal.dispatch('actionmenumessaging',
      'showNativeIconActionMenu', { config: config });
 };

  /**
   * Called by the native code when the icon action menu is hidden.
   */
  messagingApi.onIconActionMenuDidHide = function() {
    if (messagingApi.onIconActionMenuHideCallback_) {
      messagingApi.onIconActionMenuHideCallback_();
      messagingApi.onIconActionMenuHideCallback_ = undefined;
    }
  };

  navigator.actionMenuNativeMessaging = messagingApi;
})();
