// Copyright 2012 Google Inc. All Rights Reserved.

/**
 * @fileoverview Implementation of the communication protocol between the batch
 * actions menu in JavaScript and the native app.
 * @author balogan@google.com (Bryan Logan)
 */

(function() {
  if (!navigator || navigator.bamenuNativeMessaging) {
    return;
  }

  var messagingApi = {
    apiVersion: 1
  };

  /**
   * Called by JavaScript to set the message on the netstat bar.
   * @param {string} message The message to put on the netstat bar.
   * @param {boolean=} opt_displayOnRight If true, put the message on the right
   *     side of the netstat bar, otherwise, put the message on the left side.
   */
  messagingApi.setNetstatMessage = function(message, opt_displayOnRight) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'setNetstatMessage', { message: message,
            displayOnRight: !!opt_displayOnRight });
  };

  /**
   * Called by JavaScript to show or hide the netstat bar.
   * @param {boolean} display If true, show the netstat bar, otherwise, hide it.
   */
  messagingApi.showNetstat = function(display) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'showNetstatBar', { display: !!display });
  };

  /**
   * Called by JavaScript when a notification should be shown on the butter bar.
   * @param {string} notificationText The notification that should be displayed.
   * @param {number} showTime The number of milliseconds to show the
   *     notification for.
   */
  messagingApi.butterBarShowNotification = function(notificationText,
      showTime) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'butterBarShowNotification', { notificationText: notificationText,
            showTime: showTime });
  };

  /**
   * Called by JavaScript when the butter bar should hide.
   */
  messagingApi.butterBarHide = function() {
    navigator.googleInternal.dispatch('bamenunativemessaging', 'butterBarHide');
  };

  /**
   * Called by JavaScript to update the selected conversation count shown on the
   * batch actions menu.
   * @param {number} count The count of selected conversations to display.
   */
  messagingApi.bamenuSetSelectedCount = function(count) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'bamenuSetSelectedCount', { count: count });
  };

  /** Called by JavaScript to show the netstat bar batch actions menu. */
  messagingApi.bamenuShow = function() {
    navigator.googleInternal.dispatch('bamenunativemessaging', 'bamenuShow');
  };

  /** Called by JavaScript to hide the netstat bar batch actions menu. */
  messagingApi.bamenuHide = function() {
    navigator.googleInternal.dispatch('bamenunativemessaging', 'bamenuHide');
  };

  /**
   * Called by the Javascript to update the contents of the batch actions menu.
   * @param {string} config Serialized proto array representing the
   *     savannah.bamenu.BatchActionsMenu.Config to render.
   * @param {number} selectedCount The count of selected conversations to
   *     display.
   */
  messagingApi.bamenuMaybeRender = function(config, selectedCount) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'bamenuMaybeRender', { config: config, selectedCount: selectedCount });
  };

  /**
   * Called by JavaScript to show or hide the more menu for the batch actions
   * menu.
   * @param {boolean} show True to show the more menu, false to hide it.
   */
  messagingApi.bamenuShowMoreMenu = function(show) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'bamenuShowMoreMenu', { show: show });
  };

  /**
   * Called by JavaScript to show an undo-related message.
   * @param {string} message The message to display.
   * @param {number} showTime how long to show the message for.
   */
  messagingApi.showUndoMessage = function(message, showTime) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'bamenuShowUndoMessage', { message: message, showTime: showTime});
  };

  /**
   * Called by javascript to show or hide the undoing spinner.
   * @param {boolean} show True if the spinner should be shown, false otherwise.
   */
  messagingApi.showUndoingSpinner = function(show) {
    navigator.googleInternal.dispatch('bamenunativemessaging',
        'bamenuShowUndoingSpinner', {show: show});
  }

  navigator.bamenuNativeMessaging = messagingApi;
})();
